@@ -26,7 +26,7 @@ def docs():
         "[3] ssap.bsfcmap(speed,torque,bsfc,title,level)\n"
         "[4] ssap.dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,title)\n"
         "[5] ssap.dutycycle3d(speed,torque,colnum,title)\n"
-        "[6] ssap.boxplot01(x,label,title)\n"
+        "[6] ssap.boxplot01(par,label,title)\n"
     )
 
     # explain details:
@@ -70,12 +70,14 @@ def link():
         "[6] pypi step2 | twine upload dist/*\n"
     )
 
+
 # basic introduction
 def info():
     print('Welcome to SSAP! SSAP→[Self Service Analytics Platform]. There are different analytics function modules to '
           'support you complete different data analytics scenarios. Please enjoy! Any question or support needed, '
           'please raise in Big Data Community(BDC).')
 
+
 # bsfcmap | 20.dec.09
 def bsfcmap(speed, torque, bsfc, title, level):
     x = np.array(speed)
@@ -100,6 +102,7 @@ def bsfcmap(speed, torque, bsfc, title, level):
     plt.title(title)
     plt.show()
 
+
 # dutycycle | 20.dec.10
 def dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,bubblesize,title):
     x = speed
@@ -127,6 +130,7 @@ def dutycycle(speed,torque,x1,x2,stepx,y1,y2,stepy,bubblesize,title):
     ax.set_title(title)
     plt.show()
 
+
 # dutycycle3d plot | 20.dec.14
 def dutycycle3d(speed, torque, colnum, title):
     from mpl_toolkits.mplot3d import Axes3D
@@ -170,9 +174,8 @@ def dutycycle3d(speed, torque, colnum, title):
     ax.set_title(title)
     plt.show()
 
+
 # boxplot01 (single boxplot, 1 parameter, details info) | 20.dec.14
-
-
 def boxplot01(par,label,title):
     import matplotlib.pyplot as plt
     import pandas as pd
@@ -210,4 +213,74 @@ def boxplot01(par,label,title):
 
     plt.show()
 
-# boxplot02 (multiple boxplot)
\ No newline at end of file
+
+# boxplot02 (same parameter, different gategory)
+def boxplot02(dataset, title):
+    import matplotlib.pyplot as plt
+    import numpy as np
+
+    group = []
+    medians = []
+    std_err = []
+
+    df = dataset
+
+    # get all columns names, medians, std_errs
+    for i in df.iloc[:, :].columns:
+        dfi = df[i]
+        group.append(dfi)
+        medians.append(np.mean(df[i]))
+        std_err.append(np.std(df[i]))
+
+    # start chart layout
+    fig1, ax1 = plt.subplots()
+
+    num_boxes = len(list(df))
+    pos = np.arange(num_boxes) + 1
+    word_colors = ['steelblue', 'darkorange']
+
+    # 01-show medium value
+    upper_labels = ['Mean:' + str(np.round(s, 1)) for s in medians]
+
+    for tick, label in zip(range(num_boxes), ax1.get_xticklabels()):
+        #     k = tick % 2
+        ax1.text(pos[tick], .96, upper_labels[tick],
+                 transform=ax1.get_xaxis_transform(),
+                 horizontalalignment='center', size='small',
+                 weight='semibold', color=word_colors[0])
+
+    # 02-show standard error value
+    upper_labels = ['Std_Err:' + str(np.round(s, 1)) for s in std_err]
+
+    for tick, label in zip(range(num_boxes), ax1.get_xticklabels()):
+        #     k = tick % 2
+        ax1.text(pos[tick], .93, upper_labels[tick],
+                 transform=ax1.get_xaxis_transform(),
+                 horizontalalignment='center', size='small',
+                 weight='semibold', color=word_colors[1])
+
+    # 03-change abnormal format
+    red_square = dict(markerfacecolor='lightgrey', marker='o', alpha=0.5, lw=1)
+    bx = ax1.boxplot(group, flierprops=red_square, patch_artist=True)
+
+    # 04-change boxplot colors:
+    for patch in bx['boxes']:
+        patch.set_facecolor('lightgrey')
+
+    # 05-chart title
+    ax1.set_title(title)
+
+    # 06-change x ticks
+    xticks = list(df)
+    ax1.set_xticklabels(xticks, rotation=45, fontsize=8)
+
+    # 07-add grid lines
+    ax1.yaxis.grid(True)
+
+    plt.show()
+
+
+# boxplot03 (differrent parameter, same category)
+
+
+# map (with province / city)
\ No newline at end of file
